/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import {openToast} from 'frontend-js-web';

import updateFormItemConfigAction from '../actions/updateFormItemConfig';
import FormService from '../services/FormService';

export default function updateFormItemConfig({fields, itemConfig, itemId}) {
	const isMapping = Boolean(itemConfig.classNameId);

	return (dispatch, getState) => {
		return FormService.updateFormItemConfig({
			fields,
			itemConfig,
			itemId,
			onNetworkStatus: dispatch,
			segmentsExperienceId: getState().segmentsExperienceId,
		}).then(
			({
				addedFragmentEntryLinks,
				errorMessage,
				layoutData,
				removedFragmentEntryLinkIds,
			}) => {
				dispatch(
					updateFormItemConfigAction({
						addedFragmentEntryLinks,
						isMapping,
						itemId,
						layoutData,
						removedFragmentEntryLinkIds,
					})
				);

				if (errorMessage) {
					openToast({
						message: errorMessage,
						type: 'danger',
					});
				}
				else if (isMapping && itemConfig.classNameId !== '0') {
					openToast({
						message: Liferay.Language.get(
							'your-form-has-been-successfully-loaded'
						),
						type: 'success',
					});
				}
			}
		);
	};
}
